---
title: llarp/ev/vpn.hpp

---

# llarp/ev/vpn.hpp



## Namespaces

| Name           |
| -------------- |
| **[llarp](Namespaces/namespacellarp.md)** <br>[crypto.hpp] |
| **[llarp::vpn](Namespaces/namespacellarp_1_1vpn.md)**  |

## Classes

|                | Name           |
| -------------- | -------------- |
| struct | **[llarp::vpn::InterfaceAddress](Classes/structllarp_1_1vpn_1_1InterfaceAddress.md)**  |
| struct | **[llarp::vpn::InterfaceInfo](Classes/structllarp_1_1vpn_1_1InterfaceInfo.md)**  |
| class | **[llarp::vpn::NetworkInterface](Classes/classllarp_1_1vpn_1_1NetworkInterface.md)** <br>a vpn network interface  |
| class | **[llarp::vpn::IRouteManager](Classes/classllarp_1_1vpn_1_1IRouteManager.md)**  |
| class | **[llarp::vpn::Platform](Classes/classllarp_1_1vpn_1_1Platform.md)** <br>a vpn platform responsible for obtaining vpn interfaces  |




## Source code

```cpp
#pragma once

#include <llarp/net/ip_range.hpp>
#include <llarp/net/ip_packet.hpp>
#include <set>

#include <oxenc/variant.h>

namespace llarp
{
  struct Context;
  struct AbstractRouter;
}  // namespace llarp

namespace llarp::vpn
{
  struct InterfaceAddress
  {
    constexpr InterfaceAddress(IPRange r, int f = AF_INET) : range{std::move(r)}, fam{f}
    {}
    IPRange range;
    int fam;
    bool
    operator<(const InterfaceAddress& other) const
    {
      return range < other.range or fam < other.fam;
    }
  };

  struct InterfaceInfo
  {
    std::string ifname;
    huint32_t dnsaddr;
    std::set<InterfaceAddress> addrs;
  };

  class NetworkInterface
  {
   public:
    NetworkInterface() = default;
    NetworkInterface(const NetworkInterface&) = delete;
    NetworkInterface(NetworkInterface&&) = delete;

    virtual ~NetworkInterface() = default;

    virtual int
    PollFD() const = 0;

    virtual std::string
    IfName() const = 0;

    virtual net::IPPacket
    ReadNextPacket() = 0;

    virtual bool
    WritePacket(net::IPPacket pkt) = 0;

    virtual void
    MaybeWakeUpperLayers() const {};
  };

  class IRouteManager
  {
   public:
    using IPVariant_t = std::variant<huint32_t, huint128_t>;

    IRouteManager() = default;
    IRouteManager(const IRouteManager&) = delete;
    IRouteManager(IRouteManager&&) = delete;
    virtual ~IRouteManager() = default;

    virtual void
    AddRoute(IPVariant_t ip, IPVariant_t gateway) = 0;

    virtual void
    DelRoute(IPVariant_t ip, IPVariant_t gateway) = 0;

    virtual void
    AddDefaultRouteViaInterface(std::string ifname) = 0;

    virtual void
    DelDefaultRouteViaInterface(std::string ifname) = 0;

    virtual void
    AddRouteViaInterface(NetworkInterface& vpn, IPRange range) = 0;

    virtual void
    DelRouteViaInterface(NetworkInterface& vpn, IPRange range) = 0;

    virtual std::vector<IPVariant_t>
    GetGatewaysNotOnInterface(std::string ifname) = 0;

    virtual void
    AddBlackhole(){};

    virtual void
    DelBlackhole(){};
  };

  class Platform
  {
   public:
    Platform() = default;
    Platform(const Platform&) = delete;
    Platform(Platform&&) = delete;
    virtual ~Platform() = default;

    virtual std::shared_ptr<NetworkInterface>
    ObtainInterface(InterfaceInfo info, AbstractRouter* router) = 0;

    virtual IRouteManager&
    RouteManager() = 0;
  };

  std::shared_ptr<Platform>
  MakeNativePlatform(llarp::Context* ctx);

}  // namespace llarp::vpn
```


-------------------------------

Updated on 2022-07-24 at 00:14:35 +0000
