---
title: llarp::net
summary: get a sock addr we can use for all interfaces given our public address 

---

# llarp::net

get a sock addr we can use for all interfaces given our public address 

## Classes

|                | Name           |
| -------------- | -------------- |
| struct | **[llarp::net::ip_header_le](Classes/structllarp_1_1net_1_1ip__header__le.md)**  |
| struct | **[llarp::net::ip_header_le< false >](Classes/structllarp_1_1net_1_1ip__header__le_3_01false_01_4.md)**  |
| struct | **[llarp::net::ipv6_header_preamble_le](Classes/structllarp_1_1net_1_1ipv6__header__preamble__le.md)**  |
| struct | **[llarp::net::ipv6_header_preamble_le< false >](Classes/structllarp_1_1net_1_1ipv6__header__preamble__le_3_01false_01_4.md)**  |
| struct | **[llarp::net::ipv6_header](Classes/structllarp_1_1net_1_1ipv6__header.md)**  |
| struct | **[llarp::net::IPPacket](Classes/structllarp_1_1net_1_1IPPacket.md)** <br>an Packet  |
| struct | **[llarp::net::IPRangeMap](Classes/structllarp_1_1net_1_1IPRangeMap.md)** <br>a container that maps an ip range to a value that allows you to lookup key by range hit  |
| struct | **[llarp::net::ProtocolInfo](Classes/structllarp_1_1net_1_1ProtocolInfo.md)** <br>information about an IP protocol  |
| struct | **[llarp::net::TrafficPolicy](Classes/structllarp_1_1net_1_1TrafficPolicy.md)** <br>information about what traffic an endpoint will carry  |

## Types

|                | Name           |
| -------------- | -------------- |
| enum class uint8_t | **[IPProtocol](Namespaces/namespacellarp_1_1net.md#enum-ipprotocol)** { ICMP = 0x01, IGMP = 0x02, IPIP = 0x04, TCP = 0x06, UDP = 0x11, GRE = 0x2F, ICMP6 = 0x3A, OSFP = 0x59, PGM = 0x71}<br>"well known" ip protocols TODO: extend this to non "well known values"  |
| using [ip_header_le](Classes/structllarp_1_1net_1_1ip__header__le.md)< oxenc::little_endian > | **[ip_header](Namespaces/namespacellarp_1_1net.md#using-ip-header)**  |

## Functions

|                | Name           |
| -------------- | -------------- |
| [huint128_t](Classes/structllarp_1_1huint__t.md) | **[In6ToHUInt](Namespaces/namespacellarp_1_1net.md#function-in6tohuint)**(in6_addr addr) |
| in6_addr | **[HUIntToIn6](Namespaces/namespacellarp_1_1net.md#function-huinttoin6)**([huint128_t](Classes/structllarp_1_1huint__t.md) x) |
| constexpr [huint128_t](Classes/structllarp_1_1huint__t.md) | **[ExpandV4](Namespaces/namespacellarp_1_1net.md#function-expandv4)**([huint32_t](Classes/structllarp_1_1huint__t.md) x) |
| constexpr [huint128_t](Classes/structllarp_1_1huint__t.md) | **[ExpandV4Lan](Namespaces/namespacellarp_1_1net.md#function-expandv4lan)**([huint32_t](Classes/structllarp_1_1huint__t.md) x) |
| constexpr [huint32_t](Classes/structllarp_1_1huint__t.md) | **[TruncateV6](Namespaces/namespacellarp_1_1net.md#function-truncatev6)**([huint128_t](Classes/structllarp_1_1huint__t.md) x) |
| std::string | **[IPProtocolName](Namespaces/namespacellarp_1_1net.md#function-ipprotocolname)**([IPProtocol](Namespaces/namespacellarp_1_1net.md#enum-ipprotocol) proto)<br>get string representation of this protocol throws std::invalid_argument if we don't know the name of this ip protocol  |
| [IPProtocol](Namespaces/namespacellarp_1_1net.md#enum-ipprotocol) | **[ParseIPProtocol](Namespaces/namespacellarp_1_1net.md#function-parseipprotocol)**(std::string data)<br>parse a string to an ip protocol throws std::invalid_argument if cannot be parsed  |
| uint16_t | **[ipchksum](Namespaces/namespacellarp_1_1net.md#function-ipchksum)**(const byte_t * buf, size_t sz, uint32_t sum =0)<br>generate ip checksum  |
| std::optional< [SockAddr](Classes/structllarp_1_1SockAddr.md) > | **[AllInterfaces](Namespaces/namespacellarp_1_1net.md#function-allinterfaces)**([SockAddr](Classes/structllarp_1_1SockAddr.md) pubaddr) |
| std::string | **[LoopbackInterfaceName](Namespaces/namespacellarp_1_1net.md#function-loopbackinterfacename)**()<br>get the name of the loopback interface  |

## Types Documentation

### enum IPProtocol

| Enumerator | Value | Description |
| ---------- | ----- | ----------- |
| ICMP | 0x01|   |
| IGMP | 0x02|   |
| IPIP | 0x04|   |
| TCP | 0x06|   |
| UDP | 0x11|   |
| GRE | 0x2F|   |
| ICMP6 | 0x3A|   |
| OSFP | 0x59|   |
| PGM | 0x71|   |



"well known" ip protocols TODO: extend this to non "well known values" 

### using ip_header

```cpp
using llarp::net::ip_header = typedef ip_header_le<oxenc::little_endian>;
```



## Functions Documentation

### function In6ToHUInt

```cpp
huint128_t In6ToHUInt(
    in6_addr addr
)
```


### function HUIntToIn6

```cpp
in6_addr HUIntToIn6(
    huint128_t x
)
```


### function ExpandV4

```cpp
constexpr huint128_t ExpandV4(
    huint32_t x
)
```


### function ExpandV4Lan

```cpp
constexpr huint128_t ExpandV4Lan(
    huint32_t x
)
```


### function TruncateV6

```cpp
constexpr huint32_t TruncateV6(
    huint128_t x
)
```


### function IPProtocolName

```cpp
std::string IPProtocolName(
    IPProtocol proto
)
```

get string representation of this protocol throws std::invalid_argument if we don't know the name of this ip protocol 

### function ParseIPProtocol

```cpp
IPProtocol ParseIPProtocol(
    std::string data
)
```

parse a string to an ip protocol throws std::invalid_argument if cannot be parsed 

### function ipchksum

```cpp
uint16_t ipchksum(
    const byte_t * buf,
    size_t sz,
    uint32_t sum =0
)
```

generate ip checksum 

### function AllInterfaces

```cpp
std::optional< SockAddr > AllInterfaces(
    SockAddr pubaddr
)
```


### function LoopbackInterfaceName

```cpp
std::string LoopbackInterfaceName()
```

get the name of the loopback interface 





-------------------------------

Updated on 2022-07-24 at 00:14:34 +0000